//[mahjong-utils](../../../index.md)/[mahjongutils.yaku](../index.md)/[Yakus](index.md)/[Yakus](-yakus.md)

# Yakus

[common]\
constructor(options: [HoraOptions](../../mahjongutils.hora/-hora-options/index.md))
